@@ -3,11 +3,10 @@ from ovirt_hosted_engine_ha.env import constants
 import ovfenvelope
 import logging
 
-RES_ALLOCATION_ROOT_NS = 'http://schemas.dmtf.org/wbem/wscim/1/cim-schema' \
-                         '/2/CIM_ResourceAllocationSettingData'
 RES_ALLOCATION_NS = \
-    'Content/Section/Item/{' + \
-    RES_ALLOCATION_ROOT_NS + \
+    'Content/Section/Item/{' \
+    'http://schemas.dmtf.org/wbem/wscim/1/cim-schema' \
+    '/2/CIM_ResourceAllocationSettingData' \
     '}'
 
 OVF_NS = \
@@ -237,10 +236,7 @@ def toDict(ovf):
     # mem
     # TODO use it to convert memSize
     # unit = text(tree, RES_ALLOCATION_NS + 'AllocationUnits')
-    mem_items = tree.xpath("//Item[res:ResourceType[text()='4']]"
-                           "/res:VirtualQuantity/text()",
-                           namespaces={"res": RES_ALLOCATION_ROOT_NS})
-    vmParams['memSize'] = mem_items[0]
+    vmParams['memSize'] = text(tree, RES_ALLOCATION_NS + 'VirtualQuantity')
 
     # devices
     vmParams['devices'] = devices = []
@@ -290,7 +286,7 @@ def toDict(ovf):
 def confFromOvf(ovf):
     """
 
-    :param  ovf: path to the OVF file
+    :param  ovf: contents of the OVF file
     :type ovf: str
     :return:  key=value representation of the VM from ovf,
               consumable as a conf file
@@ -312,7 +308,8 @@ def confFromOvf(ovf):
 
 
 if __name__ == '__main__':
-    print(confFromOvf(open(sys.argv[1], 'r')))
+    with open(sys.argv[1], 'r') as ovf_file:
+        print(confFromOvf(ovf_file.read()))
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
